
clear all
clf

%% TAR INN S11 VERDIER FOR ALLE MLINGENE %%%
l = [ 'refmet.d1'; 'DATA11.d1';'DATA00.d1'; 'DATA01.d1'; 'DATA02.d1'; 'DATA03.d1'; 'DATA04.d1'; 'DATA05.d1'; 'DATA06.d1'; 'DATA07.d1'; 'DATA08.d1'; 'DATA09.d1'];
celldata = cellstr(l);
%filnavn = ['refmet.d1'; 'Type1_luft'; 'Type1_3mm.d1'; 'Type1_10mm.d1'; 'Type1_30mm.d1';'Type1_50mm.d1'; 'Type1_70mm.d1'; 'Type1_80mm.d1'; 'Type1_90mm.d1'; 'Type1_100mm.d1'; 'Type1_150mm.d1'; 'Type1_200mm.d1' ];

sattLevel = [0 0 3 10 30 50 70 80 90 100 150 200];

for p = 1:12
    v = celldata(p);
    
    s11 = importdata(char(v) , ',', 9);
    verdier(p) = s11;
    s11Real = s11.data(:,1);                        
    s11Imag = s11.data(:,2);
    maaling = (s11Real - j*s11Imag);
    refl(:,p) = maaling;                     % Putting the measured data in table.
end


%% KONSTANTER %%%
N = length(refl(:,1));
n = 1:N;

freq = 9+2*1602/1601*(n-1)/N;
c = 300;                                            %Speed of light in mmGHz
k = 2*pi*freq/c;                                    %Wave number
F = c/sqrt(1)/2/(freq(N)-(2*freq(1)-freq(2)));      %Fourier step. LNG 1.67, Parafine 2.25
bw = freq(N)-(2*freq(1)-freq(2));                   %Bandwith...

%% ANALYSE / TRANSFORM %%%
han = HANN(N)';                                     % Hanning window with length N. Matlab function..

for r = 1:12
analysehan = 2*ifft(han.*refl(:,r)');               % Transformation and Hanning weighting. *2 to get the same are /energy as for rect. window
powhan = (abs(analysehan).^2);                      % Power specter
[a b] = max(powhan(20:30));                         % Max point of power specter. b forteller oss ved hvilket pkt (reelt b-1...) 
b = b+19;                                           %Compenasation due to segment...
b_mat(:,r) = b;                                           
cog = b-1 + sum((-2:2).*powhan(b-2:b+2))/sum(powhan(b-2:b+2));   % Center Of Gravity. A measure of distance to the wanted echo. 
                                                                 % Number of rounds in the revolution counter.
cog_mat(:,r) = cog;
avst_mat(:,r) = cog*F;
diff_mat(:,r) = avst_mat(:,1) - avst_mat(:,r);
Pcog = (2/3)*sum(powhan(b-2:b+2));
Pcog_mat(:,r) = Pcog;
PcogdB = 10*log10(Pcog);
PcogdB_mat(:,r) = PcogdB;

navn(:,r) = [celldata(r) PcogdB avst_mat(r)/1000 ]%sattLevel(r) sattLevel(r)-diff_mat(r)/1000 diff_mat(r)/1000];
end

avst_mat(10:12) = avst_mat(9) + (avst_mat(10:12)-avst_mat(9))*0.936;
ullage_mat = avst_mat(1)-avst_mat;

%% Values for pkt 3 and 4 %%

list_number = 11;
ullage = cog_mat(list_number)*F;
ext=16;
M=N*ext; z=(1:M)/ext;  

%pkt 3
integrand3 = han.*refl(:,list_number)'; integrand3(N+1:M)=zeros(size(N+1:M));
avstand3=2*ext*ifft(integrand3); %for pkt 3
powhan_pkt3 = (abs(analysehan).^2);
[amp3 pos3]=max(powhan_pkt3(8:12));
pos3 = pos3 + 7;
cog_pkt3 = pos3-1 + sum((-2:2).*powhan_pkt3(pos3-2:pos3+2))/sum(powhan_pkt3(pos3-2:pos3+2));
amp3=-10*log10(1/amp3)

%pkt 4      
integrand = han.*refl(:,list_number)'; integrand(N+1:M)=zeros(size(N+1:M)); %Padding
avstand4=2*ext*ifft(integrand);
powhan_pkt4 = abs(avstand4(floor(20*ext):floor(ext*30))).^2; %i ekko pkt
[amp4 pos4]=max(powhan_pkt4);
pos4 = pos4 + 19;
cog_pkt4 = pos4-1 + sum((-2:2).*powhan_pkt4(pos4-2:pos4+2))/sum(powhan_pkt4(pos4-2:pos4+2))
amp4=-10*log10(1/amp4)

%pkt 5

integrand5 = han.*refl(:,list_number)'; integrand(N+1:M)=zeros(size(N+1:M)); %Padding
avstand5=2*ext*ifft(integrand5);
powhan_pkt5 = abs(avstand5(floor(25*ext):floor(ext*30))).^2; %i ekko pkt
[amp5 pos5]=max(powhan_pkt5);
pos5 = pos5 + 24;
cog_pkt5 = pos5-1 + sum((-2:2).*powhan_pkt5(pos5-2:pos5+2))/sum(powhan_pkt5(pos5-2:pos5+2))
amp5=-10*log10(1/amp5)

%% PLOT %%
figure(1)
plot( sattLevel, PcogdB_mat, [60 100], [-20 -15], 'r' , [60 250], [-20 -20],'r',  [100 250], [-15 -15], 'r' )
axis ([0 200 -25 -10])
grid
xlabel('Measured level, mm')
ylabel('Echo amplitude, dB')
title('Echo signal')
legend ('Echo strength', 'Waveguide')

figure(2)
subplot(2,1,1)
plot( sattLevel, (avst_mat(1)-avst_mat), [85 85], [0 250], 'black', [0 200],[0 200], 'r' ) 
grid
xlabel('Real level, mm')
ylabel('Ullage, dB')
title('Ullage vs real level')
legend ('Ullage vs real level', 'Half the outlet covered', 'zero difference')
subplot(2,1,2)
plot( sattLevel, (avst_mat(1)-avst_mat)-sattLevel)
grid
xlabel('Real level, mm ')
ylabel('Difference, mm')
title('Difference between ullage and real level')
%legend ('Echo strength', 'Waveguide')

figure(3)
plot((z-z(1))*F ,20*log10(abs(avstand4)),ullage,amp4,'or', cog_pkt5*F, amp5, 'or')
axis([0 3000 -80 0])
grid
xlabel('Distance, mm')
ylabel('Echo amplitude, dB')
title('Echo signal')
legend('Echo signal vs. Measured distance','Maximum for the wanted echo')
%figure(4)
%plot(n, 20*log10((2*ifft(han.*refl(:,2)'))))

