clear all
clf
%% DATA IMPORT %%%
s11 = importdata('Type1_luft.d1', ',', 9);
s11Real = s11.data(:,1);                        
s11Imag = s11.data(:,2);

s11_2 = importdata('Type2_luft.d1', ',', 9);
s11Real_2 = s11_2.data(:,1);                        
s11Imag_2 = s11_2.data(:,2);

s11_refmet = importdata('refmet.d1', ',', 9);
s11_refmetReal = s11_refmet.data(:,1);
s11_refmetImag = s11_refmet.data(:,2);


%%  BACKSCATTER %%%
refl = (s11Real - j*s11Imag);                       % Measured / S11 complex..
refl_2 = (s11Real_2 - j*s11Imag_2);
refl_refmet = (s11_refmetReal - j*s11_refmetImag);  % Data for referance measurement. (e.g metal --> shortcircuit.)


%%  CONSTANTS %%%
N = length(refl);
n = 1:N;

freq = 9+2*1602/1601*(n-1)/N;
c = 300;                                            %Speed of light given in mmGHz
k = 2*pi*freq/c;                                    %Wave number
F = c/sqrt(1)/2/(freq(N)-(2*freq(1)-freq(2)));      %Fourier step. LNG 1.67, Paraffin 2.25
bw = freq(N)-(2*freq(1)-freq(2));                   %bandwith...
%hann = 2*sin(pi*n/N).^2;                           %hanning..


%%  ANALYSis / TRANSFORM %%%
han = 2*sin(pi*(n-1/2)/N).^2;                       % Hanning window of length N
analyse = ifft(refl');                              % Transoformation to time domain
analyse_2 = ifft(refl_2');
analyse_refmet = ifft(refl_refmet');

analysehan_refmet = 2*ifft(han.*refl_refmet');        % Transform og Hanning veiing av mledata til referanse
powhan_refmet = (abs(analysehan_refmet).^2);        % Finner power spekter til referanse signal. Absolut verdi kvadrert.
[a b] = max(powhan_refmet);                         % Finner maxpunkt til power spekter. b forteller oss ved hvilket pkt (reelt b-1...)
cog_refmet = b-1 + sum((-2:2).*powhan_refmet(b-2:b+2))/sum(powhan_refmet(b-2:b+2))     %finner Center Of Gravity. Forteller oss hvor mye man m "nste tilbake"
Pcog = 2/3*sum(powhan_refmet(b-2:b+2))        %finner energien i maks.                                                                      %for  flytte planet ned til absorbenten. Nyaktig antall runder p "turtelleren"
                                                        
analysehan = 2*ifft(han.*refl');       %samme som for referansen....
powhan = (abs(analysehan).^2);         
[a b] = max(powhan(20:30)); 
b= b+19                                                            % ikke maks ekko for nsket puls siden dette er svakt.. velger da  lete innenfor et visst omrde, her ellom pkt 20 og 30.
cog = b-1 + sum((-2:2).*powhan(b-2:b+2))/sum(powhan(b-2:b+2)) % center of gravity. m legge til punkter ti  l b siden max tatt av utsnitt

analysehan_2 = 2*ifft(han.*refl_2');       %samme som for referansen....
powhan_2 = (abs(analysehan_2).^2);         
[a b] = max(powhan_2(20:30)); 
b= b+19                                                              % ikke maks ekko for nsket puls siden dette er svakt.. velger da  lete innenfor et visst omrde, her ellom pkt 20 og 30.
cog_2 = b-1 + sum((-2:2).*powhan_2(b-2:b+2))/sum(powhan_2(b-2:b+2)) % center of gravity. m legge til punkter ti  l b siden max tatt av utsnitt


%% FILTER %%%%
analysefilt = analysehan;          
analysefilt(1:20)=zeros(size(1:20)); analysefilt(31:1601)=zeros(size(31:1601)); % setter pkt.prve 1 til 20 og 31 til 1601 =0. nsket ekko ligger emllom 20 og 30.

analysefilt_refmet = analysehan_refmet;
analysefilt_refmet(1:20)=zeros(size(1:20)); analysefilt_refmet(31:1601)=zeros(size(31:1601));

analysefilt_2 = analysehan_2;
analysefilt_2(1:20)=zeros(size(1:20)); analysefilt_2(31:1601)=zeros(size(31:1601));

%% SHIFT %%%%
 reflfilthan = fft(analysefilt);
 reflfilt = reflfilthan.*(1./han);  %fjerner hanning
 reflfiltBand = reflfilt;   
 reflfiltBand(1:100)= zeros(size(1:100)); reflfiltBand((1601-100):1601)=zeros(size((1601-100):1601));
 reflshift = reflfiltBand.*exp(j*2*pi*cog_refmet*n/N);

 reflfilthan_refmet=fft(analysefilt_refmet);
 reflfilt_refmet = reflfilthan_refmet.*(1./han); 
 reflfiltBand_refmet = reflfilt_refmet;
 reflfiltBand_refmet(1:100)= zeros(size(1:100)); reflfiltBand_refmet((1601-100):1601)=zeros(size((1601-100):1601));
 reflshift_refmet = reflfiltBand_refmet.*exp(j*2*pi*cog_refmet*n/N);

 reflfilthan_2=fft(analysefilt_2);
 reflfilt_2 = reflfilthan_2.*(1./han); 
 reflfiltBand_2 = reflfilt_2;
 reflfiltBand_2(1:100)= zeros(size(1:100)); reflfiltBand_2((1601-100):1601)=zeros(size((1601-100):1601));
 reflshift_2 = reflfiltBand_2.*exp(j*2*pi*cog_refmet*n/N);

%% IMPEDANCE CALCULATIONS %%
 
 reflAbs_korr1 = reflshift./(-reflshift_refmet);
 reflAbs_korr2 = reflshift_2./(-reflshift_refmet);
 Zabs_1 = 377*((1+reflAbs_korr1)./(1-reflAbs_korr1));
 Zabs_2 = 377*((1+reflAbs_korr2)./(1-reflAbs_korr2)); 
 
%% VSWR CIRCLE %%

s = 1.2;
center = 250*(s+(1/s))/2
radius = 250*(s-(1/s))/2

G=1000;
angle=0:1/G:2*pi;
x1= center +(radius*cos(angle));
y1=radius*sin(angle);

%% PLOT %%
figure(1)

 subplot(2,1,1)
 plot((n-1)*F, 20*log10(abs(analyse)))
 axis([0 3000 -70 0])
 title ('Backscatter in time domain.')
 xlabel('Distance in mm')
 ylabel('Reflection in dB')
 grid
 subplot(2,1,2)
 plot((n-1)*F, 20*log10(abs(analysehan)))%
 axis([0 3000 -70 0])
 title ('Backscatter in time domain with hanningweighing .')
 xlabel('Distance in mm')
 ylabel('Reflection in dB') 
 grid

 
%figure(2)
% plot(freq, angle(reflfilt))%, n , angle(reflshift_refmet), 'r')
 grid on
 title ('Output.')
 xlabel('Frequency [GHz]')
 ylabel('Amplitude') 
 
 
figure(3)
 plot(freq, real(Zabs_2), freq, imag(Zabs_2))
 axis([9.2 10.8 -100 300])
 legend('Real part', 'Imaginary part')
 title ('Measured impedance of the Bottom Absorber Type2.')
 xlabel('Frequency (GHz)')
 ylabel('Impedance (Ohm)') 
 grid on

figure(4)
plot(real(Zabs_1), imag(Zabs_1), real(Zabs_2), imag(Zabs_2), 'r', x1, y1, 'black', real(Zabs_1(801)), imag(Zabs_1(801)), 'or', real(Zabs_2(801)), imag(Zabs_2(801)), 'or')
%axis('equal');

 legend('Type1', 'Type2', 'VSWR = 1.2', 'Value at 10GHz')
 title ('Input Impedance of bottom absorbers vs VSWR circle.')
 xlabel('Real part (Ohm)')
 ylabel('Imaginary part (Ohm)') 
grid