clear all;
clf
%% Constants
Er = 10.5 - j*0.3; 
Ur = 1.2-j*0.5;               %permability
E0=8.8541878176e-12;            %permittivity of vacum
U0=4*pi*10^-7;                  %permability of vacum
c=3e8;                          %speed of light
f=10e9;                         %frequency
la=c/f;                         %wavelength
w = 2*pi*f;                     %angular fequency
Z_LNG = 292;
Z0 = 377;
Z_par = 251;
T = 0:0.0000001:.01;            %
k = 0:0.00001:1;

Zr = sqrt((Ur*U0)/(Er*E0));     %intrinsic impedance 
Yr = ((j*w)/c)*(sqrt(Er*Ur));   %The propagation constant depends on the radar frequency
Z=(Zr*tanh(Yr*T));              %input impedance



%% Combination with given thickness.
t1=2.0/1000;        %imag = 0   re=412.8
t2=4.0/1000;        %imag=0     re=109.3
t3=6.00/1000;       %imag=0     re=174

Z1=(Zr*tanh(Yr*t1));       %input impedance
Z2=(Zr*tanh(Yr*t2));
Z3=(Zr*tanh(Yr*t3));

%% LNG %%
Gamma1=((Z1)-Z_LNG)/((Z1)+Z_LNG);    %Reflection coeff with LNG with given thickness
Gamma3=((Z3)-Z_LNG)/((Z3)+Z_LNG);

Gamma_t1_t3 = k.*Gamma1 + (1-k).*Gamma3;

%% PARAFFIN %%

Gamma1_par=((Z1)-Z_par)/((Z1)+Z_par)    
Gamma3_par=((Z3)-Z_par)/((Z3)+Z_par);

Gamma_par = k.*Gamma1_par + (1-k).*Gamma3_par;

%% PLOT %%
figure(1)
    plot(k, real(Gamma_t1_t3))
    title ('Ratio of combination with t=2mm and t=6mm')
    xlabel('Ratio k')
    ylabel('Real part of summarized reflection, real (  \Gamma_\Sigma)')
    axis([0 1 -0.25 0.2])
    grid on

figure(2)
    plot(k, real(Gamma_par))
    title ('Ratio of combination with t=2mm and t=6mm')
    xlabel('Ratio k')
    ylabel('Real part of summarized reflection, real (  \Gamma_\Sigma)')
    axis([0 1 -0.25 0.2])
    grid on

%% Gamma values for given $k_2$

%Gamma12 = 0.7728*Gamma1 + (1-0.7728)*Gamma2    
Gamma13 = 0.5949*Gamma1 + (1-0.5949)*Gamma3

%Gamma12_test = 0.6*Gamma1 + (1-0.6)*Gamma2    
Gamma_par_test = 0.4*Gamma1_par + (1-0.4)*Gamma3_par


