clear all;
clf
%% Constants
Er = 10.5 - j*0.3; 
Ur = 1.2-j*0.5;               %permability
E0=8.8541878176e-12;            %permittivity of vacum
U0=4*pi*10^-7;                  %permability of vacum
c=3e8;                          %speed of light
f=10e9;                         %frequency
la=c/f;                         %wavelength
w = 2*pi*f;                     %angular fequency

Z_lng = 292;
Z_par = 251;
Z0 = 377;

T = 0:0.0000001:.01;            %
k = 0:0.00001:1;

%% IMPEDANCE %%
Zr = sqrt((Ur*U0)/(Er*E0));     %intrinsic impedance 
Yr = ((j*w)/c)*(sqrt(Er*Ur));   %The propagation constant depends on the radar frequency
Z=(Zr*tanh(Yr*T));              %input impedance

t1=2.0/1000;        %imag = 0   re=412.8
t2=4.0/1000;        %imag=0     re=109.3
t3=6.00/1000;       %imag=0     re=174

Z1=(Zr*tanh(Yr*t1));       %input impedance
Z2=(Zr*tanh(Yr*t2));
Z3=(Zr*tanh(Yr*t3));


%% AIR %%
Gamma1_air=((Z1)-Z0)/((Z1)+Z0)    
Gamma3_air=((Z3)-Z0)/((Z3)+Z0);

Gamma_air = k.*Gamma1_air + (1-k).*Gamma3_air;
Zl_air = Z0.*(1+Gamma_air)./(1-(Gamma_air));

%% Paraffin %%
Gamma1_par=((Z1)-Z_par)/((Z1)+Z_par)    
Gamma3_par=((Z3)-Z_par)/((Z3)+Z_par);

Gamma_par = k.*Gamma1_par + (1-k).*Gamma3_par;
Zl_par = Z_par.*(1+Gamma_par)./(1-(Gamma_par));

%% LNG %%
Gamma1_lng=((Z1)-Z_lng)/((Z1)+Z_lng)    
Gamma3_lng=((Z3)-Z_lng)/((Z3)+Z_lng);

Gamma_lng = k.*Gamma1_lng + (1-k).*Gamma3_lng;
Zl_lng = Z_lng.*(1+Gamma_lng)./(1-(Gamma_lng));

%% PLOT %%
figure(1)
plot(k, real(Zl_air), k, real(Zl_par), 'r',  [0 1], [real(Z3) real(Z1)],...
    'black', [.4 .6] , [251 292], 'black o', [.4268], [251],'black x')
title ('Ratio with respectively air and paraffin as reference')
xlabel('Ratio k')
ylabel('Real part of input impedance')
grid on
legend('Impedance vs ratio with air as reference', 'Impedance vs ratio with paraffin as reference',.... 
'Linear ratio from 414.9 (t=2mm) to 172.7 (t=6mm)','Ratio obtained with EMDS ', 'Calculated ratio for paraffin')
axis ([0 1 150 450])
